@@ -4,7 +4,7 @@ use warnings;
 use Devel::DTrace::Provider::Builder;
 
 provider 'provider1' => as {
-    probe 'probe1', 'string';
+    probe 'probe1-start', 'string';
     probe 'probe2', 'integer';
 };
 
